  ########################
  #### function is.D2 ####
  ########################


is.D2 <- function(x){
	return(inherits(x,"D2"))
	}